﻿namespace UltraChartCompositeChart
{
    using System.Collections.Generic;
    using System.Drawing;
    using System.Windows.Forms;
    using Infragistics.UltraChart.Core.Layers;
    using Infragistics.UltraChart.Resources.Appearance;
    using Infragistics.UltraChart.Shared.Styles;
    using Infragistics.Win.UltraWinChart;

    public partial class Form1 : Form
    {
        public object HashTable { get; private set; }

        public Form1()
        {
            InitializeComponent();
            this.SetUpChart(this.ultraChart1);
        }

        private void SetUpChart(UltraChart chart)
        {
            //  Set the chart type to Composite
            chart.ChartType = ChartType.Composite;

            //  Add chart area where all charts will be painted
            ChartArea chartArea = new ChartArea();
            chart.CompositeChart.ChartAreas.Add(chartArea);

            //  Add X axis for column chart
            AxisItem axisXSeries = new AxisItem();
            axisXSeries.OrientationType = AxisNumber.X_Axis;
            axisXSeries.DataType = AxisDataType.String;
            axisXSeries.Labels.ItemFormat = AxisItemLabelFormat.None;
            axisXSeries.SetLabelAxisType = SetLabelAxisType.GroupBySeries;

            //  Add X axis for line chart
            AxisItem axisXLine = new AxisItem();
            axisXLine.OrientationType = AxisNumber.X_Axis;
            axisXLine.DataType = AxisDataType.Numeric;

            //  Hide the axis labels as you will show column chart series labels
            axisXLine.Labels.ItemFormat = AxisItemLabelFormat.None;

            //  Set up axis range to fit line points with columns
            axisXLine.RangeType = AxisRangeType.Custom;
            axisXLine.RangeMin = 0;
            axisXLine.RangeMax = 12;
            axisXLine.TickmarkInterval = 1;
            axisXLine.TickmarkStyle = AxisTickStyle.Smart;

            // Add Y axis. You will use same Y axis for both charts
            AxisItem axisY = new AxisItem();
            axisY.OrientationType = AxisNumber.Y_Axis;
            axisY.DataType = AxisDataType.Numeric;
            axisY.Labels.ItemFormatString = "<DATA_VALUE:0.#>";

            //  Set up the range as in your image
            axisY.RangeType = AxisRangeType.Custom;
            axisY.RangeMin = -20;
            axisY.RangeMax = 30;
            axisY.TickmarkStyle = AxisTickStyle.Smart;
            axisY.TickmarkInterval = 5;

            chartArea.Axes.Add(axisXSeries);
            chartArea.Axes.Add(axisXLine);
            chartArea.Axes.Add(axisY);

            //  Create and add all the column series
            NumericSeries[] columnSeries = this.GetColumnSeries();
            chart.CompositeChart.Series.AddRange(columnSeries);

            //  Create and add the line series
            XYSeries lineSeries = this.GetLineSeries();
            chart.CompositeChart.Series.Add(lineSeries);

            //  Add and set up column layer. This layer will render column chart
            ChartLayerAppearance columnLayer = new ChartLayerAppearance();
            columnLayer.ChartType = ChartType.ColumnChart;
            columnLayer.ChartArea = chartArea;
            columnLayer.AxisX = axisXSeries;
            columnLayer.AxisY = axisY;
            columnLayer.Series.AddRange(columnSeries);
            chart.CompositeChart.ChartLayers.Add(columnLayer);

            //  Create column appearance to set up column chart outlook
            ColumnChartAppearance columnAppearance = new ColumnChartAppearance();
            columnAppearance.ColumnSpacing = 0;
            columnAppearance.SeriesSpacing = 0;
            columnLayer.ChartTypeAppearance = columnAppearance;

            //  To show values above each column add ChartTextAppearance to
            //  ColumnChartAppearance. Set Row and Column properties to -2.
            //  This will force chart to paint all the column values
            ChartTextAppearance columnText = new ChartTextAppearance();
            columnText.Row = -2;
            columnText.Column = -2;
            columnText.Visible = true;
            columnText.VerticalAlign = StringAlignment.Far;
            columnAppearance.ChartText.Add(columnText);

            //  Add and set up line layer. This layer will render line chart
            ChartLayerAppearance lineLayer = new ChartLayerAppearance();
            lineLayer.ChartType = ChartType.ScatterChart;
            lineLayer.ChartArea = chartArea;
            lineLayer.Series.Add(lineSeries);
            lineLayer.AxisX = axisXLine;
            lineLayer.AxisY = axisY;
            chart.CompositeChart.ChartLayers.Add(lineLayer);

            //  Create scatter appearance to set up line chart outlook
            ScatterChartAppearance scatterAppearance = new ScatterChartAppearance();
            scatterAppearance.ConnectWithLines = true;
            scatterAppearance.LineAppearance.SplineTension = 0;
            scatterAppearance.LineAppearance.Thickness = 1;
            scatterAppearance.Icon = SymbolIcon.X;
            scatterAppearance.IconSize = SymbolIconSize.Small;
            lineLayer.ChartTypeAppearance = scatterAppearance;

            //  Add ChartTextAppearance and for line chart. Same as above
            ChartTextAppearance lineText = new ChartTextAppearance();
            lineText.Row = -2;
            lineText.Column = -2;
            lineText.Visible = true;
            lineText.ItemFormatString = "<DATA_VALUE_Y>";
            lineText.VerticalAlign = StringAlignment.Far;
            scatterAppearance.ChartText.Add(lineText);
        }

        private NumericSeries[] GetColumnSeries()
        {
            List<NumericSeries> series = new List<NumericSeries>();

            NumericSeries seriesPC = new NumericSeries();
            seriesPC.Label = "PC";
            seriesPC.Points.Add(new NumericDataPoint(10, "Max", false));
            seriesPC.Points.Add(new NumericDataPoint(7, "Min", false));
            series.Add(seriesPC);

            NumericSeries seriesMAC = new NumericSeries();
            seriesMAC.Label = "MAC";
            seriesMAC.Points.Add(new NumericDataPoint(10, "Max", false));
            seriesMAC.Points.Add(new NumericDataPoint(10, "Min", false));
            series.Add(seriesMAC);

            NumericSeries seriesUnix = new NumericSeries();
            seriesUnix.Label = "Unix";
            seriesUnix.Points.Add(new NumericDataPoint(7, "Max", false));
            seriesUnix.Points.Add(new NumericDataPoint(12, "Min", false));
            series.Add(seriesUnix);

            NumericSeries seriesIrix = new NumericSeries();
            seriesIrix.Label = "Irix";
            seriesIrix.Points.Add(new NumericDataPoint(25, "Max", false));
            seriesIrix.Points.Add(new NumericDataPoint(-12, "Min", false));
            series.Add(seriesIrix);

            NumericSeries seriesLinux = new NumericSeries();
            seriesLinux.Label = "Linux";
            seriesLinux.Points.Add(new NumericDataPoint(13, "Max", false));
            seriesLinux.Points.Add(new NumericDataPoint(-3, "Min", false));
            series.Add(seriesLinux);

            NumericSeries seriesVMS = new NumericSeries();
            seriesVMS.Label = "VMS";
            seriesVMS.Points.Add(new NumericDataPoint(15, "Max", false));
            seriesVMS.Points.Add(new NumericDataPoint(15, "Min", false));
            series.Add(seriesVMS);

            return series.ToArray();
        }

        private XYSeries GetLineSeries()
        {
            XYSeries series = new XYSeries();
            series.Label = "Line";

            series.Points.Add(new XYDataPoint(1, 8, "PC", false));
            series.Points.Add(new XYDataPoint(3, 10, "MAC", false));
            series.Points.Add(new XYDataPoint(5, 10, "Unix", false));
            series.Points.Add(new XYDataPoint(7, -1, "Irix", false));
            series.Points.Add(new XYDataPoint(9, -15, "Linux", false));
            series.Points.Add(new XYDataPoint(11, 15, "VMS", false));

            return series;
        }
    }
}
